<?php

namespace B2buy\Payment\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Payment\Http\Requests\PaymentRequest;
use B2buy\Payment\Interfaces\PaymentRepositoryInterface;
use B2buy\Payment\Models\Payment;
use B2buy\Payment\Forms\Payment as Form;

/**
 * APIController  class for payment.
 */
class PaymentAPIController extends BaseController
{

    /**
     * Initialize payment resource controller.
     *
     * @param type PaymentRepositoryInterface $payment
     *
     * @return null
     */
    public function __construct(PaymentRepositoryInterface $payment)
    {
        parent::__construct();
        $this->repository = $payment;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Payment\Repositories\Criteria\PaymentResourceCriteria::class);
    }

    /**
     * Display a list of payment.
     *
     * @return Response
     */
    public function index(PaymentRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Payment\Repositories\Presenter\PaymentPresenter::class)
            ->paginate();
    }

    /**
     * Display payment.
     *
     * @param Request $request
     * @param Model   $payment
     *
     * @return Response
     */
    public function show(PaymentRequest $request, Payment $payment)
    {
        return $payment->setPresenter(\B2buy\Payment\Repositories\Presenter\PaymentListPresenter::class);
        ;
    }

    /**
     * Create new payment.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PaymentRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('payment::payment.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('payment/payment/' . $payment->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('payment/payment');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the payment.
     *
     * @param Request $request
     * @param Model   $payment
     *
     * @return Response
     */
    public function update(PaymentRequest $request, Payment $payment)
    {
        try {
            $data = $request->all();

            $payment->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('payment::payment.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('payment/payment/' . $payment->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('payment/payment/' . $payment->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the payment.
     *
     * @param Model   $payment
     *
     * @return Response
     */
    public function destroy(PaymentRequest $request, Payment $payment)
    {
        try {
            $payment->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('payment::payment.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('payment/payment/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('payment/payment/' . $payment->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
