<?php

namespace B2buy\Payment\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Payment\Models\Payment;

class PaymentPolicy
{

    /**
     * Determine if the given user can view the payment.
     *
     * @param UserPolicy $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function view(UserPolicy $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.view') && $user->isAdmin()) {
            return true;
        }

        return $payment->user_id == user_id() && $payment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a payment.
     *
     * @param UserPolicy $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('payment.payment.create');
    }

    /**
     * Determine if the given user can update the given payment.
     *
     * @param UserPolicy $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function update(UserPolicy $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.edit') && $user->isAdmin()) {
            return true;
        }

        return $payment->user_id == user_id() && $payment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given payment.
     *
     * @param UserPolicy $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Payment $payment)
    {
        return $payment->user_id == user_id() && $payment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given payment.
     *
     * @param UserPolicy $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given payment.
     *
     * @param UserPolicy $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
