<?php

namespace B2buy\Payment\Workflow;

use B2buy\Payment\Models\Payment;
use Validator;

class PaymentValidator
{

    /**
     * Determine if the given payment is valid for complete status.
     *
     * @param Payment $payment
     *
     * @return bool / Validator
     */
    public function complete(Payment $payment)
    {
        return Validator::make($payment->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given payment is valid for verify status.
     *
     * @param Payment $payment
     *
     * @return bool / Validator
     */
    public function verify(Payment $payment)
    {
        return Validator::make($payment->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given payment is valid for approve status.
     *
     * @param Payment $payment
     *
     * @return bool / Validator
     */
    public function approve(Payment $payment)
    {
        return Validator::make($payment->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given payment is valid for publish status.
     *
     * @param Payment $payment
     *
     * @return bool / Validator
     */
    public function publish(Payment $payment)
    {
        return Validator::make($payment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given payment is valid for archive status.
     *
     * @param Payment $payment
     *
     * @return bool / Validator
     */
    public function archive(Payment $payment)
    {
        return Validator::make($payment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given payment is valid for unpublish status.
     *
     * @param Payment $payment
     *
     * @return bool / Validator
     */
    public function unpublish(Payment $payment)
    {
        return Validator::make($payment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
